pub enum FileType {
Regular {
executable: bool,
},
Directory,
Symlink,
}Expand description
The type of a file.
This mirrors the variants of FileNode, but without storing
data in each variant.
An exception to this is the executable field for the regular type.
This is needed since we present regular and executable files as different
to the user, so we need a way to represent both types.
Variants