pub struct FileTreeEntry {
pub path: Vec<u8>,
pub node: FileNode<()>,
}Expand description
An entry in a file tree is a path to a node paired with that node.
If the entry refers to a directory, it only stores information about that directory itself. It does not contain the children of the directory.
Fields
path: Vec<u8>node: FileNode<()>Implementations